@@ -1037,6 +1037,9 @@ NMEA_PAYLOADS_GET_PROP = {
         "enabled": IN,
     },
     "AIR437": {"enabled": IN},
+    "AIR491": {
+        "enabled": IN,
+    },
     "AIR650": {
         "second": IN,
     },
@@ -1046,6 +1049,10 @@ NMEA_PAYLOADS_GET_PROP = {
     "AIR867": {
         "flowControl": IN,
     },
+    "AIR6011": {
+        "type": IN,
+        "rate": IN,
+    },
     "AIRSPF": {
         "status": IN,
     },
@@ -1069,10 +1076,31 @@ NMEA_PAYLOADS_GET_PROP = {
         "status": QS,  # ERROR
         "errcode": IN,  # 1 = invalid parms, 2 = failed exec, 3 = unsupported
     },
+    "QTMANTENNASTATUS": {
+        "msgver": IN,  # always 1 for this version
+        "antennastatus": IN,
+        "antennapowerind": IN,
+    },
     "QTMCFGAIC": {
         "status": QS,
         "state": IN,
     },
+    "QTMCFGANTDELTA": {
+        "status": QS,
+        "east": DE,
+        "north": DE,
+        "height": DE,
+    },
+    "QTMCFGANTINF": {
+        "status": QS,
+        "antennadesc": ST,
+        "antennasetupid": IN,
+        "antennasn": ST,
+    },
+    "QTMCFGBLD": {
+        "status": QS,
+        "distance": DE,
+    },
     "QTMCFGCNST": {
         "status": QS,
         "gps": IN,
@@ -1082,6 +1110,23 @@ NMEA_PAYLOADS_GET_PROP = {
         "qzss": IN,
         "navic": IN,
     },
+    "QTMCFGDR": {
+        "status": QS,
+        "drstate": IN,
+    },
+    "QTMCFGDRHOT": {"status": QS, "mode": IN},
+    "QTMCFGDRRTD": {"status": QS, "time": IN, "distance": IN},
+    "QTMCFGEINSMSG": {
+        "type": IN,
+        "ins_enabled": IN,
+        "imu_enabled": IN,
+        "gps_enabled": IN,
+        "rate": IN,
+    },
+    "QTMCFGELETHD": {
+        "status": QS,
+        "elevation": DE,
+    },
     "QTMCFGFIXRATE": {
         "status": QS,
         "fixinterval": IN,
@@ -1116,6 +1161,33 @@ NMEA_PAYLOADS_GET_PROP = {
         "lat3": DE,
         "lon3": DE,
     },
+    "QTMCFGGEOSEP": {
+        "status": QS,
+        "mode": IN,
+        "geosep": DE,
+    },
+    "QTMCFGIMUINT": {
+        "status": QS,
+        "index": IN,
+        "mode": IN,
+        "reserved": IN,
+        "actLevel": IN,
+    },
+    "QTMCFGIMUTC": {
+        "status": QS,
+        "imustatus": IN,
+    },
+    "QTMCFGLA": {
+        "status": QS,
+        "type": IN,
+        "laX": DE,
+        "laY": DE,
+        "laZ": DE,
+    },
+    "QTMCFGLAM": {
+        "status": QS,
+        "mode": IN,
+    },
     "QTMCFGMSGRATE": {
         "status": QS,
         "msgname": ST,
@@ -1127,6 +1199,21 @@ NMEA_PAYLOADS_GET_PROP = {
         "msgname": ST,
         "rate": IN,
     },
+    "QTMCFGMSGRATE_INTF": {
+        "status": QS,
+        "porttype": IN,  # 1 = UART
+        "portid": IN,  # 1 =UART1, 2 = UART2, 3 = UART3
+        "msgname": ST,
+        "rate": IN,
+        "msgver": IN,  # or offset
+    },
+    "QTMCFGMSGRATE_INTFNOVER": {
+        "status": QS,
+        "porttype": IN,  # 1 = UART
+        "portid": IN,  # 1 =UART1, 2 = UART2, 3 = UART3
+        "msgname": ST,
+        "rate": IN,
+    },
     "QTMCFGNAVMODE": {
         "status": QS,
         "mode": IN,
@@ -1178,7 +1265,7 @@ NMEA_PAYLOADS_GET_PROP = {
         "status": QS,
         "msmtype": IN,
         "msmmode": IN,
-        "msmelevthd": IN,
+        "msmelevthd": DE,
         "reserved1": ST,  # must be 07 with leading 0
         "reserved2": ST,  # must be 06 with leading 0
         "ephmode": IN,
@@ -1189,6 +1276,14 @@ NMEA_PAYLOADS_GET_PROP = {
         "diffmode": IN,  # 0 disable, 1 auto, 2 RTD only
         "relmode": IN,  # 1 absolute, 2 relative
     },
+    "QTMCFGRTKSRCTYPE": {
+        "status": QS,
+        "srctype": IN,
+    },
+    "QTMMCFGRTKSRCTYPE": {
+        "status": QS,
+        "srctype": IN,
+    },
     "QTMCFGSAT": {
         "status": QS,
         "systemid": IN,
@@ -1202,6 +1297,14 @@ NMEA_PAYLOADS_GET_PROP = {
         "signalid": ST,  # hex as string
         "masklow": ST,  # hex as string
     },
+    "QTMCFGSBAS": {
+        "status": QS,
+        "value": HX,
+    },
+    "QTMCFGSIGGRP": {
+        "status": QS,
+        "siggrpnum": IN,
+    },
     "QTMCFGSIGNAL": {
         "status": QS,
         "gpssig": ST,  # hex as string, default 07
@@ -1211,6 +1314,19 @@ NMEA_PAYLOADS_GET_PROP = {
         "qzsssig": ST,  # hex as string, default 07
         "navicsig": ST,  # hex as string, default 01
     },
+    "QTMCFGSIGNAL2": {
+        "status": QS,
+        "gpssig": ST,  # hex as string, default 07
+        "glonasssig": ST,  # hex as string, default 03
+        "galileosig": ST,  # hex as string, default 0F
+        "beidousig": ST,  # hex as string, default 3F
+        "qzsssig": ST,  # hex as string, default 07
+        "navicsig": ST,  # hex as string, default 01
+    },
+    "QTMCFGSTATICHOLD": {
+        "status": QS,
+        "shstate": IN,
+    },
     "QTMCFGSVIN": {
         "status": QS,
         "svinmode": IN,
@@ -1229,6 +1345,15 @@ NMEA_PAYLOADS_GET_PROP = {
         "stopbit": IN,
         "flowctrl": IN,
     },
+    "QTMCFGVEHMOT": {
+        "status": QS,
+        "mode": IN,
+        "vehtype": IN,
+    },
+    "QTMCFGWN": {
+        "status": QS,
+        "weekno": IN,
+    },
     "QTMDEBUGON": {"status": QS},
     "QTMDEBUGOFF": {"status": QS},
     "QTMDOP": {
@@ -1242,6 +1367,37 @@ NMEA_PAYLOADS_GET_PROP = {
         "ndop": DE,
         "edop": DE,
     },
+    "QTMDRCAL": {
+        "msgver": IN,  # always 1 for this version
+        "calstate": IN,  # 0 = none, 1 = lightly, 2 = fully
+        "navtype": IN,  # 0 = none, 1 = GNSS only, 2 = DR only, 3 = GNSS + DR
+    },
+    "QTMDRCLR": {"status": QS},
+    "QTMDRPVA": {
+        "msgver": IN,  # always 1 for this version
+        "timestamp": IN,
+        "time": DE,
+        "solType": IN,
+        "lat": DE,
+        "lon": DE,
+        "alt": DE,
+        "sep": DE,
+        "velN": DE,
+        "velE": DE,
+        "velD": DE,
+        "speed": DE,
+        "roll": DE,
+        "pitch": DE,
+        "heading": DE,
+    },
+    "QTMDRSAVE": {"status": QS},
+    "QTMEOE": {
+        "msgver": IN,  # always 2 for this version
+        "utc": DE,
+        "Date": IN,
+        "WN": IN,
+        "TOW": IN,
+    },
     "QTMEPE": {
         "msgver": IN,  # always 2 for this version
         "epenorth": DE,
@@ -1265,10 +1421,52 @@ NMEA_PAYLOADS_GET_PROP = {
     },
     "QTMGNSSSTART": {"status": QS},
     "QTMGNSSSTOP": {"status": QS},
+    "QTMGPS": {
+        "timestamp": IN,
+        "tow": IN,
+        "lat": DE,
+        "lon": DE,
+        "alt": DE,
+        "speed": DE,
+        "heading": DE,
+        "accuracy": DE,
+        "HDOP": DE,
+        "PDOP": DE,
+        "numSv": IN,
+        "fixMode": IN,
+    },
     "QTMJAMMINGSTATUS": {
         "msgver": IN,  # always 1 for this version
         "jammingstatus": IN,
     },
+    "QTMIMU": {
+        "timestamp": IN,
+        "accX": DE,
+        "accY": DE,
+        "accZ": DE,
+        "angrateX": DE,
+        "angrateY": DE,
+        "angrateZ": DE,
+        "wheeltick": IN,
+        "last_tick_timestamp": IN,
+    },
+    "QTMIMUTYPE": {
+        "msgver": IN,  # always 1 for this version
+        "imustatus": IN,  # 0 = failed, 1 = OK
+    },
+    "QTMINS": {
+        "timestamp": IN,
+        "soltype": IN,
+        "lat": DE,
+        "lon": DE,
+        "height": DE,
+        "velN": DE,
+        "velE": DE,
+        "velD": DE,
+        "roll": DE,
+        "pitch": DE,
+        "yaw": DE,
+    },
     "QTMLS": {
         "msgver": IN,  # always 1 for this version
         "tow": IN,
@@ -1282,6 +1480,51 @@ NMEA_PAYLOADS_GET_PROP = {
         "dn": IN,
         "lsf": IN,
     },
+    "QTMNAV": {
+        "msgver": IN,  # always 1 for this version
+        "timestatus": IN,
+        "timeref": IN,
+        "utc": DE,
+        "date": IN,
+        "tow": IN,
+        "wn": IN,
+        "leapsec": IN,
+        "reserved1": ST,
+        "reserved2": ST,
+        "soltype": IN,
+        "reserved3": IN,
+        "lat": DE,
+        "lon": DE,
+        "alt": DE,
+        "sep": DE,
+        "reserved4": ST,
+        "reserved5": ST,
+        "latstd": DE,
+        "lonstd": DE,
+        "altstd": DE,
+        "reserved6": ST,
+        "reserved7": ST,
+        "diffid": DE,
+        "diffAge": DE,
+        "reserved8": ST,
+        "siv": IN,
+        "sip": IN,
+        "reserved9": ST,
+        "reserved10": ST,
+        "reserved11": ST,
+        "reserved12": ST,
+        "reserved13": ST,
+        "reserved14": ST,
+        "hvel": DE,
+        "vvel": DE,
+        "hvelstd": DE,
+        "vvelstd": DE,
+        "reserved15": ST,
+        "reserved16": ST,
+        "cog": DE,
+        "reserved17": ST,
+        "reserved18": ST,
+    },
     "QTMODO": {
         "msgver": IN,  # always 1 for this version
         "time": TM,
@@ -1336,12 +1579,28 @@ NMEA_PAYLOADS_GET_PROP = {
     "QTMRESETODO": {"status": QS},
     "QTMRESTOREPAR": {"status": QS},
     "QTMSAVEPAR": {"status": QS},
+    "QTMSENMSG": {
+        "msgver": IN,  # 2 or 4
+        "timestamp": IN,
+        "group": (
+            "None",
+            {
+                "sensor_info": DE,
+            },
+        ),
+    },
     "QTMSN": {
         "status": QS,
         "snid": IN,  # fixed to 1
         "length": IN,
         "serialno": ST,
     },
+    "QTMSN_ALT": {
+        "snid": IN,  # fixed to 1
+        "length": IN,
+        "status": QS,
+        "serialno": ST,
+    },
     "QTMSTD": {
         "reserved": ST,
         "utc": TM,
@@ -1372,6 +1631,20 @@ NMEA_PAYLOADS_GET_PROP = {
         "meanz": DE,
         "meanacc": DE,
     },
+    "QTMTAR": {
+        "msgver": IN,  # always 1 for this version
+        "time": DE,
+        "quality": DE,
+        "res": DE,
+        "length": DE,
+        "pitch": DE,
+        "roll": DE,
+        "heading": DE,
+        "accpitch": DE,
+        "accroll": DE,
+        "accheading": DE,
+        "usedsv": IN,
+    },
     "QTMTXT": {
         "msgver": IN,  # always 1 for this version
         "totalsennum": IN,
@@ -1384,6 +1657,35 @@ NMEA_PAYLOADS_GET_PROP = {
         "length": IN,
         "ID": HX,
     },
+    "QTMVEHATT": {
+        "msgver": IN,  # always 1 for this version
+        "timestamp": IN,
+        "roll": DE,
+        "pitch": DE,
+        "heading": DE,
+        "acc_Roll": DE,
+        "acc_Pitch": DE,
+        "acc_Heading": DE,
+    },
+    "QTMVEHMOT": {
+        "msgver": IN,  # 1 or 2
+        "group": (
+            "None",
+            {
+                "vehicle_info": DE,
+            },
+        ),
+    },
+    "QTMVEHMSG": {
+        "msgver": IN,  # 1 = speed, 2 = tick, 3 = speed 4wd, 4 = ticks 4wd
+        "timestamp": IN,
+        "group": (
+            "None",
+            {
+                "vehicle_info": DE,
+            },
+        ),
+    },
     "QTMVEL": {
         "msgver": IN,  # always 1 for this version
         "time": TM,
@@ -1410,6 +1712,287 @@ NMEA_PAYLOADS_GET_PROP = {
         "buildtime": ST,  # hh:mm:ss
     },
     # ***************************************************************
+    # Quectel LG69T PSTM Proprietary message types
+    # https://quectel.com/content/uploads/2024/09/quectel_lg69taaadafaiajar_gnss_protocol_specification_v1-5.pdf
+    # ***************************************************************
+    "STMPPSDATA": {
+        "onoff": IN,
+        "ppsvalid": IN,
+        "syncvalid": IN,
+        "outmode": IN,
+        "reftime": IN,
+        "refconst": IN,
+        "pulseduration": DE,  # second pulse duration.
+        "pulsedelay": DE,  # nanosecond pulse delay.
+        "gpsdelay": DE,  # nanosecond gps path rf delay.
+        "reserved1": ST,
+        "bdsdelay": DE,  # nanosecond bds path rf delay.
+        "galileodelay": DE,  # nanosecond galileo path rf delay.
+        "invertedpolarity": IN,
+        "fixcond": IN,
+        "satth": DE,
+        "elevmask": DE,
+        "constmask": IN,
+        "refsec": DE,  # second
+        "fixstatus": DE,
+        "usedsats": DE,  #  used satellites for time correction.
+        "gpsutcdeltas": DE,  # second utc leap seconds.
+        "gpsutcdeltans": DE,  # nanosecond utc–gps delta time.
+        "reserved2": ST,
+        "galileoutcdeltans": DE,  # nanosecond utc–galileo delta time.
+        "quantizationerror": DE,  # second quantization error.
+        "ppsclockfreq": DE,  # hz pps clock frequency.
+        "tcxoclockfreq": DE,  # hz tcxo clock frequency.
+        "bdsutcdeltatimes": DE,  # second utc–bds leap second.
+    },
+    "STMCPU": {
+        "cpuusage": DE,  #  cpu usage in percentage (%).
+        "pllonoff": IN,
+        "cpuspeed": HX,  # hexadecimal mhz cpu clock frequency.
+    },
+    "STMTG": {
+        "wno": IN,  #  week number.
+        "tow": DE,  # second time of week.
+        "reserved1": ST,  # reserved
+        "cputime": DE,  #  cpu time.
+        "timevalid": IN,
+        "nco": DE,  # hz
+        "configstatus": HX,  # hexadecimal
+        "constmask": IN,
+        "timebestsattype": IN,  #  selected best time satellite type.
+        "timemastersattype": IN,  #  master time satellite type.
+        "timemasterwn": IN,  #  master time week number.
+        "timemastertow": DE,  # second master time tow.
+        "timemastervalidity": DE,  # master week number time validity.
+        "tgauxflags": IN,
+        "clockbias": DE,  # meter estimated receiver clock bias.
+        "mfreqconfigmask": DE,  #  multifrequency configuration mask.
+        "leapsec": IN,  # second
+        "ppsedge": DE,  #  pps edge counter @ 64f0 resolution.
+        "mtbms": DE,  # millisecond
+        "mtbtimestamp": DE,  # picosecond
+    },
+    "STMTS": {
+        "dspdat": IN,
+        "satid": IN,  #  satellite identifier.
+        "psr": DE,  # meter pseudo range.
+        "freq": DE,  #  satellite tracking frequency offset.
+        "cp": DE,  # cycle carrier phase measurement.
+        "dspflags": IN,
+        "satcn0": DE,  # dbhz satellite carrier to noise ratio.
+        "ttim": DE,  # second track time of satellite.
+        "codenoise": DE,
+        "phasenoise": DE,
+        "cycleslipcnt": DE,  #  total cycle slip counter.
+        "reserved1": ST,
+        "elev": DE,  # degree elevation degree.
+    },
+    "STMSBAS": {
+        "status": IN,
+        "sattrk": IN,
+        "satid": IN,  #  sbas satellite id.
+        "elev": DE,  # degree sbas satellite elevation.
+        "azim": DE,  # degree sbas satellite azimuth.
+        "satcn0": DE,  # dbhz sbas satellite signal strength c/n0.
+    },
+    "STMTEMP": {
+        "temperature": DE,
+        "rawtemperature": DE,
+        "calibration": IN,
+    },
+    "STMDRCONFID": {
+        "latstddev": DE,  # meter latitude standard deviation.
+        "lonstddev": DE,  # meter longitude standard deviation.
+        "headingstddev": DE,  # degree heading standard deviation.
+        "reserved1": ST,
+        "gyrobiasstddev": DE,  # millivolt gyroscope bias standard deviation.
+        "odoscalestddev": DE,  # millimeter/pulse odometer scale standard deviation.
+        "reserved2": ST,
+        "accoffsetstddev": DE,  # g accelerometer offset standard deviation.
+        "heightstddev": DE,  # meter height standard deviation.
+        "majorsemiaxis": DE,  # meter major semiaxis of 1sigma error ellipse.
+        "minorsemiaxis": DE,  # meter minor semiaxis of 1sigma error ellipse.
+        "ellipseangle": DE,  # degree angle vs north of 1sigma error ellipse.
+        "speedstddev": DE,  # m/s speed standard deviation.
+    },
+    "STMDRBSD": {
+        "timestamp": DE,
+        "cputime": IN,  #  time of dr estimation (cpu ticks).
+        "gyroxbiassd": DE,  # dps gyroscope x bias standard deviation.
+        "gyroybiassd": DE,  # dps gyroscope y bias standard deviation.
+        "gyrozbiassd": DE,  # dps gyroscope z bias standard deviation.
+        "accxbiassd": DE,  # m/s2 accelerometer x bias standard deviation.
+        "accybiassd": DE,  # m/s2 accelerometer y bias standard deviation.
+        "acczbiassd": DE,  # m/s2 accelerometer z bias standard deviation.
+    },
+    "STMDRGPS": {
+        "lat": DE,  # degree gnss latitude.
+        "lon": DE,  # degree gnss longitude.
+        "vn": DE,  # m/s gnss velocity north component.
+        "ve": DE,  # m/s gnss velocity east component.
+        "pdop": DE,
+        "hdop": DE,
+        "vdop": DE,
+        "rmsposresidual": DE,  # meter rms error on gnss pseudo range measurements.
+        "rmsvelresidual": DE,  # m/s rms error on gnss frequency measurements.
+        "vup": DE,  # m/s gnss velocity up component.
+        "height": DE,  # meter gnss altitude.
+    },
+    "STMDRPVA": {
+        "timestamp": DE,
+        "cputime": IN,  # microsecond time of dr estimation (cpu ticks).
+        "latitude": DE,  # degree dr latitude.
+        "longitude": DE,  # degree dr longitude.
+        "height": DE,  # meter dr height.
+        "vnorth": DE,  # m/s dr velocity north component.
+        "veast": DE,  # m/s dr velocity east component.
+        "vup": DE,  # m/s dr velocity up component.
+        "pitch": DE,  # degree dr pitch angle. range: 90.00 to 90.00.
+        "roll": DE,  # degree dr roll angle. range: 180.00 to 180.00.
+        "heading": DE,  # degree dr heading angle. range: 0.00 to 360.00.
+    },
+    "STMDRPVASD": {
+        "timestamp": DE,
+        "cputime": IN,  # microsecond time of dr estimation (cpu ticks).
+        "latitudesd": DE,  # degree dr latitude standard deviation.
+        "longitudesd": DE,  # degree dr longitude standard deviation.
+        "heightsd": DE,  # meter dr height standard deviation.
+        "vnorthsd": DE,  # m/s dr velocity north component standard deviation.
+        "veastsd": DE,  # m/s dr velocity east component standard deviation.
+        "vupsd": DE,  # m/s dr velocity up component standard deviation.
+        "pitchsd": DE,  # degree dr pitch angle standard deviation.
+        "rollsd": DE,  # degree dr roll angle standard deviation.
+        "headingsd": DE,  # degree dr heading angle standard deviation.
+        "pnesd": DE,  # meter dr position north east standard deviation.
+        "pnusd": DE,  # meter dr position north up standard deviation.
+        "peusd": DE,  # meter dr position east up standard deviation.
+        "vnesd": DE,  # m/s dr velocity north east standard deviation.
+        "vnusd": DE,  # m/s dr velocity north up standard deviation.
+        "veusd": DE,  # m/s dr velocity east up standard deviation.
+    },
+    "STMDRSINT": {
+        "gyrosamplecount": IN,  #  number of received gyroscope samples.
+        "accsamplecount": IN,  #  number of received accelerometer samples.
+        "pressamplecount": IN,  #  number of received pressure samples.
+        "odometercount": IN,  #  number of received odometer pulses.
+        "gyrointtime": DE,  # second
+        "accinttime": DE,  # second
+        "pressureinttime": DE,  # second
+        "gyroxavg": DE,  # dps
+        "gyroyavg": DE,  # dps
+        "gyrozavg": DE,  # dps
+        "accxavg": DE,  # m/s2
+        "accyavg": DE,  # m/s2
+        "acczavg": DE,  # m/s2
+        "presavg": DE,  # hpa average of received pressure samples.
+    },
+    "STMDRSVF": {
+        "timestamp": DE,
+        "cputime": IN,  # microsecond time of estimation (cpu ticks).
+        "xacceleration": DE,  # m/s2 vehicle acceleration in x direction.
+        "yacceleration": DE,  # m/s2 vehicle acceleration in y direction.
+        "zacceleration": DE,  # m/s2 vehicle acceleration in z direction.
+        "xangularrate": DE,  # dps vehicle angular rate in x direction.
+        "yangularrate": DE,  # dps vehicle angular rate in y direction.
+        "zangularrate": DE,  # dps vehicle angular rate in z direction.
+    },
+    "STMDRUPD": {"group": ("None", {"data": HX})},
+    "STMDRSTYPE": {
+        "sensortype": IN,
+    },
+    "STMDRCAL": {
+        "driscalib": IN,
+        "odoiscalib": IN,
+        "gyrosensitivityiscalib": IN,
+        "gyrobiasiscalib": IN,
+        "imuflag": HX,
+        "gyrointegrityflag": IN,
+        "accintegrity": IN,
+        "calstate": ST,
+    },
+    "STMDR1": {
+        "mpitch": DE,  # degree misalignment sensor vs. vehicle frame – pitch angle.
+        "mroll": DE,  # degree misalignment sensor vs. vehicle frame – roll angle.
+        "myaw": DE,  # degree misalignment sensor vs. vehicle frame – yaw angle.
+        "gsz": DE,  #  gyroscope z axis sensitivity.
+        "gbx": DE,  # dps gyroscope x axis bias.
+        "gby": DE,  # dps gyroscope y axis bias.
+        "gbz": DE,  # dps gyroscope z axis bias.
+        "abx": DE,  # m/s2 accelerometer x axis bias.
+        "aby": DE,  # m/s2 accelerometer y axis bias.
+        "abz": DE,  # m/s2 accelerometer z axis bias.
+        "odometerscale": DE,  # meter/pulse odometer scale.
+        "res1baro": DE,  #  reserved for barometer.
+        "res2baro": DE,  #  reserved for barometer.
+    },
+    "STMDR2": {
+        "imucal": ST,
+        "ascal": ST,
+        "motionstatus": IN,
+        "errcode": IN,
+        "sysready": IN,
+        "crosstrackerror": DE,  # meter crosstrack error vs gnssonly mode.
+        "alongtrackerror": DE,  # meter alongtrack error vs gnssonly mode.
+        "sysaligned": IN,
+        "vrows": DE,  # meter estimated vehicle tire circumference.
+        "vrost": IN,
+    },
+    "STMDREPE": {
+        "ehpe": DE,  # meter error of dr estimated horizontal position
+        "reserved1": ST,  #  IN, # reserved fixed as 1.00.
+    },
+    "STMDRDEBUG": {
+        "laterror": DE,  # meter latitude error.
+        "lonerror": DE,  # meter longitude error.
+        "headingerror": DE,  # degree heading error.
+        "speederror": DE,  # m/s speed error.
+        "heighterror": DE,  # meter height error.
+        "vverror": DE,  # m/s rise speed error.
+    },
+    "STMDRSENMSG_3": {
+        "msgtype": IN,  # 3 = Odometer and Reverse
+        "timestamp": IN,  # microsecond cpu tick count since poweron.
+        "odometer": DE,
+        "reverse": IN,  # 0 = forward, 1 = reverse
+    },
+    "STMDRSENMSG_24": {
+        "msgtype": IN,  # 24 = IMU temperature
+        "timestamp": IN,  # microsecond cpu tick count since poweron.
+        "temperature": DE,
+        "validity": IN,
+    },
+    "STMDRSENMSG_30": {
+        "msgtype": IN,  # 30 = IMU accelerometer
+        "timestamp": IN,  # microsecond cpu tick count since poweron.
+        "xacc": DE,
+        "yacc": DE,
+        "zacc": DE,
+    },
+    "STMDRSENMSG_31": {
+        "msgtype": IN,  # 31 = IMU gyroscope
+        "timestamp": IN,  # microsecond cpu tick count since poweron.
+        "xgyro": DE,
+        "ygyro": DE,
+        "zgyro": DE,
+    },
+    "STMDRMMFBKF": {
+        "cputime": DE,  # tick
+        "elapsedtime": DE,  # tick
+        "utcdeltaseconds": DE,  # second
+        "utcdeltams": DE,
+        "posaccepted": DE,
+        "reserved1": ST,
+        "reserved2": ST,
+        "measurementnoiselat": DE,  # meter
+        "posmeasurementnoiselon": DE,  # meter
+        "reserved3": ST,
+        "reserved4": ST,
+        "headingaccepted": DE,
+        "reserved5": ST,
+        "headingmeasurementnoise": DE,  # degree
+        "reserved6": ST,
+    },
+    # ***************************************************************
     # Septentrio X5 Proprietary message types
     # https://www.septentrio.com/en/products/gnss-receivers/gnss-receiver-modules/mosaic-x5#resources
     # ***************************************************************
@@ -1496,4 +2079,14 @@ NMEA_PAYLOADS_GET_PROP = {
         "usage2324": ST,
         "usage252627": ST,
     },
+    "STMSETPAROK": {
+        "msgId": ST,
+        "status1": ST,
+        "status2": ST,
+        "status3": ST,
+    },
+    "STMINITGPSERROR": {},
+    "STMINITGPSOK": {},
+    "STMINITTIMEERROR": {},
+    "STMINITTIMEOK": {},
 }
